@@ -19,8 +19,11 @@
 
 #include <stdarg.h>
 #include <stdio.h>
+#ifndef LIBGDA_WIN32
 #include <syslog.h>
+#endif
 #include <time.h>
+#include <glib.h>
 #include <glib/gmem.h>
 #include <glib/gmessages.h>
 #include <glib/gstrfuncs.h>
@@ -45,7 +48,9 @@ gda_log_enable (void)
 {
 	log_enabled = TRUE;
 	if (!log_opened) {
+#ifndef LIBGDA_WIN32	
 		openlog (g_get_prgname (), LOG_CONS | LOG_NOWAIT | LOG_PID, LOG_USER);
+#endif		
 		log_opened = TRUE;
 	}
 }
@@ -60,7 +65,9 @@ gda_log_disable (void)
 {
 	log_enabled = FALSE;
 	if (log_opened) {
+#ifndef LIBGDA_WIN32		
 		closelog ();
+#endif
 		log_opened = FALSE;
 	}
 }
@@ -101,8 +108,11 @@ gda_log_message (const gchar *format, ...)
 	va_start (args, format);
 	msg = g_strdup_vprintf (format, args);
 	va_end (args);
-
-	syslog (LOG_USER | LOG_INFO, msg);
+#ifdef LIBGDA_WIN32
+	g_log ("Gda", G_LOG_LEVEL_INFO, "%s", msg);
+#else
+	syslog (LOG_USER | LOG_INFO, "%s", msg);
+#endif
 	g_free (msg);
 }
 
@@ -131,7 +141,10 @@ gda_log_error (const gchar * format, ...)
 	va_start (args, format);
 	msg = g_strdup_vprintf (format, args);
 	va_end (args);
-
-	syslog (LOG_USER | LOG_ERR, msg);
-	g_free (msg);
+#ifdef LIBGDA_WIN32
+	g_log ("Gda", G_LOG_LEVEL_ERROR, "%s", msg);
+#else
+	syslog (LOG_USER | LOG_ERR, "%s", msg);
+#endif
+ 	g_free (msg);
 }
