@@ -59,6 +59,8 @@ struct _GdaServerProviderClass {
 				      GdaQuarkList *params,
 				      const gchar *username,
 				      const gchar *password);
+	gboolean (* reset_connection) (GdaServerProvider *provider,
+				       GdaConnection *cnc);
 	gboolean (* close_connection) (GdaServerProvider *provider,
 				       GdaConnection *cnc);
 
@@ -113,6 +115,13 @@ struct _GdaServerProviderClass {
 	gboolean (* create_blob) (GdaServerProvider *provider,
 				  GdaConnection *cnc,
 				  GdaBlob *blob);
+	
+	gboolean (* escape_string) (GdaServerProvider *provider,
+				    GdaConnection *cnc,
+				    const gchar *from,
+				    gchar *to);
+				  
+				  
 };
 
 GType    gda_server_provider_get_type (void);
@@ -122,6 +131,8 @@ gboolean gda_server_provider_open_connection (GdaServerProvider *provider,
 					      GdaQuarkList *params,
 					      const gchar *username,
 					      const gchar *password);
+gboolean gda_server_provider_reset_connection (GdaServerProvider *provider,
+					       GdaConnection *cnc);
 gboolean gda_server_provider_close_connection (GdaServerProvider *provider,
 					       GdaConnection *cnc);
 
@@ -177,6 +188,12 @@ gboolean gda_server_provider_create_blob (GdaServerProvider *provider,
 					  GdaConnection *cnc,
 					  GdaBlob *blob);
 
+gboolean gda_server_provider_escape_string (GdaServerProvider *provider,
+					    GdaConnection *cnc,
+					    const gchar *from,
+					    gchar *to);
+	
+
 G_END_DECLS
 
 #endif
