@@ -602,16 +602,13 @@ sql_condition_stringify(sql_condition * cond)
 	case SQL_similar:
 	case SQL_not:
 	case SQL_like:
-		retval =
-		    memsql_strappend_free(sql_field_stringify(cond->d.pair.left),
-		                          memsql_strdup(" "));
-		retval =
-		    memsql_strappend_free(retval,
-		                          sql_condition_op_stringify(cond->op));
+		retval = memsql_strappend_free(sql_field_stringify(
+				cond->d.pair.left), memsql_strdup(" "));
+		retval = memsql_strappend_free(retval, 
+				sql_condition_op_stringify(cond->op));
 		retval = memsql_strappend_free(retval, memsql_strdup(" "));
-		retval =
-		    memsql_strappend_free(retval,
-		                          sql_field_stringify(cond->d.pair.right));
+		retval =  memsql_strappend_free(retval,sql_field_stringify(
+					cond->d.pair.right));
 		break;
 
 	case SQL_between:
@@ -637,84 +634,6 @@ sql_condition_stringify(sql_condition * cond)
 	return retval;
 	}
 
-static char *
-sql_table_stringify(sql_table * table)
-	{
-	char *retval = NULL;
-	GList *walk;
-
-	if (!table)
-		return NULL;
-
-	/* join type */
-	switch (table->join_type)
-		{
-	case SQL_cross_join:
-		retval = NULL;
-		break;
-	case SQL_inner_join:
-		retval = memsql_strdup(" join ");
-		break;
-	case SQL_left_join:
-		retval = memsql_strdup(" left join ");
-		break;
-	case SQL_right_join:
-		retval = memsql_strdup(" right join ");
-		break;
-	case SQL_full_join:
-		retval = memsql_strdup(" full join ");
-		break;
-		}
-
-	/* table */
-	switch (table->type)
-		{
-	case SQL_simple:
-		retval =
-		    memsql_strappend_free(retval, memsql_strdup(table->d.simple));
-		break;
-
-	case SQL_nestedselect:
-		retval = memsql_strappend_free(retval, memsql_strdup("("));
-		retval = memsql_strappend_free(retval,
-		                               sql_select_stringify(table->d.
-		                                                    select));
-		retval = memsql_strappend_free(retval, memsql_strdup(")"));
-		break;
-
-	case SQL_tablefunction:
-		retval =
-		    memsql_strappend_free(memsql_strdup(table->d.function.funcname),
-		                          memsql_strdup("("));
-		for (walk = table->d.function.funcarglist; walk != NULL;
-		        walk = walk->next)
-			{
-			retval =
-			    memsql_strappend_free(retval,
-			                          sql_field_stringify(walk->data));
-			if (walk->next)
-				retval =
-				    memsql_strappend_free(retval, memsql_strdup(", "));
-			}
-		retval = memsql_strappend_free(retval, memsql_strdup(")"));
-		break;
-	default:
-		fprintf(stderr, "Invalid table type: %d\n", table->type);
-		retval = NULL;
-		}
-
-	/* join condition */
-	if (table->join_cond)
-		{
-		retval = memsql_strappend_free(retval, memsql_strdup(" on "));
-		retval = memsql_strappend_free(retval,
-		                               sql_condition_stringify((sql_condition
-		                                                        *) table->
-		                                                       join_cond));
-		}
-
-	return retval;
-	}
 
 static char *
 sql_logic_op_stringify(sql_logic_operator op)
@@ -770,6 +689,83 @@ sql_where_stringify(sql_where * where)
 	return retval;
 	}
 
+static char *
+sql_table_stringify(sql_table * table)
+	{
+	char *retval = NULL;
+	GList *walk;
+
+	if (!table)
+		return NULL;
+
+	/* join type */
+	switch (table->join_type)
+		{
+	case SQL_cross_join:
+		retval = NULL;
+		break;
+	case SQL_inner_join:
+		retval = memsql_strdup(" join ");
+		break;
+	case SQL_left_join:
+		retval = memsql_strdup(" left join ");
+		break;
+	case SQL_right_join:
+		retval = memsql_strdup(" right join ");
+		break;
+	case SQL_full_join:
+		retval = memsql_strdup(" full join ");
+		break;
+		}
+
+	/* table */
+	switch (table->type)
+		{
+	case SQL_simple:
+		retval =
+		    memsql_strappend_free(retval, memsql_strdup(table->d.simple));
+		break;
+
+	case SQL_nestedselect:
+		retval = memsql_strappend_free(retval, memsql_strdup("("));
+		retval = memsql_strappend_free(retval,
+		                               sql_select_stringify(table->d.
+		                                                    select));
+		retval = memsql_strappend_free(retval, memsql_strdup(")"));
+		break;
+
+	case SQL_tablefunction:
+		retval =
+		    memsql_strappend_free(
+			memsql_strdup(table->d.function.funcname),		                          memsql_strdup("("));
+		for (walk = table->d.function.funcarglist; walk != NULL;
+		        walk = walk->next)
+			{
+			retval =
+			    memsql_strappend_free(retval,
+			                          sql_field_stringify(walk->data));
+			if (walk->next)
+				retval =
+				    memsql_strappend_free(retval, memsql_strdup(", "));
+			}
+		retval = memsql_strappend_free(retval, memsql_strdup(")"));
+		break;
+	default:
+		fprintf(stderr, "Invalid table type: %d\n", table->type);
+		retval = NULL;
+		}
+
+	/* join condition */
+	if (table->join_cond)
+		{
+		retval = memsql_strappend_free(retval, memsql_strdup(" on "));
+		retval = memsql_strappend_free(retval, 
+			sql_where_stringify((sql_where*)table->join_cond));
+		}
+
+	return retval;
+	}
+
 static char *
 sql_insert_stringify(sql_insert_statement * insert)
 	{
@@ -777,18 +773,19 @@ sql_insert_stringify(sql_insert_statement * insert)
 	GList *walk;
 
 	result = memsql_strdup("insert into ");
-	result = memsql_strappend_free(result, sql_table_stringify(insert->table));
+	result = memsql_strappend_free(result, 
+			sql_table_stringify(insert->table));
 
 	if (insert->fields)
 		{
 		result = memsql_strappend_free(result, memsql_strdup(" ("));
 		for (walk = insert->fields; walk != NULL; walk = walk->next)
 			{
-			result =
-			    memsql_strappend_free(result,
-			                          sql_field_stringify(walk->data));
+			result = memsql_strappend_free(result,
+			         sql_field_stringify(walk->data));
 			if (walk->next)
-				result = memsql_strappend_free(result, memsql_strdup(", "));
+				result = memsql_strappend_free(result, 
+				memsql_strdup(", "));
 			}
 		result = memsql_strappend_free(result, memsql_strdup(")"));
 		}
@@ -797,10 +794,11 @@ sql_insert_stringify(sql_insert_statement * insert)
 
 	for (walk = insert->values; walk != NULL; walk = walk->next)
 		{
-		result =
-		    memsql_strappend_free(result, sql_field_stringify(walk->data));
+		result = memsql_strappend_free(result, 
+				sql_field_stringify(walk->data));
 		if (walk->next)
-			result = memsql_strappend_free(result, memsql_strdup(", "));
+			result = memsql_strappend_free(result, 
+				memsql_strdup(", "));
 		}
 
 	result = memsql_strappend_free(result, memsql_strdup(")"));
@@ -819,34 +817,41 @@ sql_select_stringify(sql_select_statement * select)
 	char *group;
 	char *temp;
 	GList *walk;
+	sql_table *nexttable;
 	sql_order_field *orderfield;
 
 	result = memsql_strdup("select ");
 
 	if (select->distinct)
-		result = memsql_strappend_free(result, memsql_strdup("distinct "));
+		result = memsql_strappend_free(result, 
+				memsql_strdup("distinct "));
 
 	fields = NULL;
 	for (walk = select->fields; walk != NULL; walk = walk->next)
 		{
 		temp = sql_field_stringify(walk->data);
 		fields = memsql_strappend_free(fields, temp);
-
 		if (walk->next)
-			fields = memsql_strappend_free(fields, memsql_strdup(", "));
-
+			fields = memsql_strappend_free(fields, 
+					memsql_strdup(", "));
 		}
 
 	result = memsql_strappend_free(result, fields);
 	result = memsql_strappend_free(result, memsql_strdup(" from "));
-
+	/* Build the from statement part */
 	tables = NULL;
 	for (walk = select->from; walk != NULL; walk = walk->next)
 		{
 		temp = sql_table_stringify(walk->data);
 		tables = memsql_strappend_free(tables, temp);
 		if (walk->next)
-			tables = memsql_strappend_free(tables, memsql_strdup(", "));
+			{
+			nexttable = walk->next->data;
+			/* If its not a join add a , into sql statement */
+			if (nexttable->join_type == SQL_cross_join)
+				tables = memsql_strappend_free(tables, 
+					memsql_strdup(", "));
+			}
 		}
 
 	result = memsql_strappend_free(result, tables);
@@ -871,9 +876,11 @@ sql_select_stringify(sql_select_statement * select)
 			                              sql_field_name_stringify
 			                              (orderfield->name));
 			if (orderfield->order_type == SQL_desc)
-				order = memsql_strappend_free(order, memsql_strdup(" desc "));
+				order = memsql_strappend_free(order, 
+						memsql_strdup(" desc "));
 			if (walk->next)
-				order = memsql_strappend_free(order, memsql_strdup(", "));
+				order = memsql_strappend_free(order, 
+						memsql_strdup(", "));
 			}
 		}
 	else
@@ -1312,6 +1319,7 @@ sql_statement_get_tables(sql_statement * statement)
 	GList *retval = NULL;
 	GList *walk;
 	gchar *temp1, *temp2;
+	sql_table *table;
 	sql_select_statement *select;
 
 	if (!statement)
@@ -1324,9 +1332,10 @@ sql_statement_get_tables(sql_statement * statement)
 
 	for (walk = select->from; walk != NULL; walk = walk->next)
 		{
-		temp1 = sql_table_stringify(walk->data);
-		temp2 = g_strdup(temp1);
-		memsql_free(temp1);
+		table = walk->data;
+/*		temp1 = sql_table_stringify(walk->data); */
+		temp2 = g_strdup(table->d.simple);
+/*		memsql_free(temp1); */
 
 		retval = g_list_append(retval, temp2);
 		}
