@@ -41,8 +41,9 @@ static GObjectClass *parent_class = NULL;
  * Private functions
  */
 
-void
-fill_gda_value (GdaValue *gda_value, enum enum_field_types type, gchar *value, unsigned long length)
+static void
+fill_gda_value (GdaValue *gda_value, enum enum_field_types type, gchar *value,
+		unsigned long length, gboolean is_unsigned)
 {
 	if (!value) {
 		gda_value_set_null (gda_value);
@@ -58,18 +59,34 @@ fill_gda_value (GdaValue *gda_value, enum enum_field_types type, gchar *value, u
 		gda_value_set_single (gda_value, atof (value));
 		break;
 	case FIELD_TYPE_LONG :
+		if (is_unsigned) {
+			gda_value_set_uinteger (gda_value, strtoul (value, NULL, 0));
+			break;
+		}
 	case FIELD_TYPE_YEAR :
 		gda_value_set_integer (gda_value, atol (value));
 		break;
 	case FIELD_TYPE_LONGLONG :
 	case FIELD_TYPE_INT24 :
-		gda_value_set_bigint (gda_value, atoll (value));
+		if (is_unsigned) {
+			gda_value_set_biguint (gda_value, strtoull (value, NULL, 0));
+		} else {
+			gda_value_set_bigint (gda_value, atoll (value));
+		}
 		break;
 	case FIELD_TYPE_SHORT :
-		gda_value_set_smallint (gda_value, atoi (value));
+		if (is_unsigned) {
+			gda_value_set_smalluint (gda_value, atoi (value));
+		} else {
+			gda_value_set_smallint (gda_value, atoi (value));
+		}
 		break;
 	case FIELD_TYPE_TINY :
-		gda_value_set_tinyint (gda_value, atoi (value));
+		if (is_unsigned) {
+			gda_value_set_tinyuint (gda_value, atoi (value));
+		} else {
+			gda_value_set_tinyint (gda_value, atoi (value));
+		}
 		break;
 	case FIELD_TYPE_TINY_BLOB :
 	case FIELD_TYPE_MEDIUM_BLOB :
@@ -85,17 +102,23 @@ fill_gda_value (GdaValue *gda_value, enum enum_field_types type, gchar *value, u
 		gda_value_set_string (gda_value, value);
 		break;
 	case FIELD_TYPE_DATE :
+		gda_value_set_from_string (gda_value, value, GDA_VALUE_TYPE_DATE);
+		break;
+	case FIELD_TYPE_TIME :
+		gda_value_set_from_string (gda_value, value, GDA_VALUE_TYPE_TIME);
+		break;
+	case FIELD_TYPE_TIMESTAMP :
+	case FIELD_TYPE_DATETIME :
+		gda_value_set_from_string (gda_value, value, GDA_VALUE_TYPE_TIMESTAMP);
+		break;
 	case FIELD_TYPE_NULL :
 	case FIELD_TYPE_NEWDATE :
 	case FIELD_TYPE_ENUM :
-	case FIELD_TYPE_TIMESTAMP :
-	case FIELD_TYPE_DATETIME :
-	case FIELD_TYPE_TIME :
 	case FIELD_TYPE_SET : /* FIXME */
 		gda_value_set_string (gda_value, value);
 		break;
 	default :
-		g_printerr ("Unknown MySQL datatype.  This is fishy, but continueing anyway.\n");
+		g_printerr ("Unknown MySQL datatype.  This is fishy, but continuing anyway.\n");
 		gda_value_set_string (gda_value, value);
 	}
 }
@@ -142,9 +165,10 @@ fetch_row (GdaMysqlRecordset *recset, gulong rownum)
 
 	for (i = 0; i < field_count; i++) {
 		fill_gda_value ((GdaValue*) gda_row_get_value (row, i),
-			    mysql_fields[i].type,
-			    mysql_row[i],
-			    mysql_lengths[i]);
+				mysql_fields[i].type,
+				mysql_row[i],
+				mysql_lengths[i],
+				mysql_fields[i].flags & UNSIGNED_FLAG);
 	}
 
 	return row;
@@ -210,7 +234,8 @@ gda_mysql_recordset_describe_column (GdaDataModel *model, gint col)
 	gda_field_attributes_set_table (attrs, mysql_field->table);
 	/* gda_field_attributes_set_caption(attrs, ); */
 	gda_field_attributes_set_scale (attrs, mysql_field->decimals);
-	gda_field_attributes_set_gdatype (attrs, gda_mysql_type_to_gda (mysql_field->type));
+	gda_field_attributes_set_gdatype (attrs, gda_mysql_type_to_gda (mysql_field->type,
+									mysql_field->flags & UNSIGNED_FLAG));
 	gda_field_attributes_set_allow_null (attrs, !IS_NOT_NULL (mysql_field->flags));
 	gda_field_attributes_set_primary_key (attrs, IS_PRI_KEY (mysql_field->flags));
 	gda_field_attributes_set_unique_key (attrs, mysql_field->flags & UNIQUE_KEY_FLAG);
